@@ -20,12 +20,13 @@
 #' @param train.p numeric. What percentage of the data to use for training when \code{data.test} is not specified? For example, \code{train.p = .5} will randomly split \code{data} into a 50\% training set and a 50\% test set. \code{train.p = 1}, the default, uses all data for training.
 #' @param rounding integer. An integer indicating digit rounding for non-integer numeric cue thresholds. The default is NULL which means no rounding. A value of 0 rounds all possible thresholds to the nearest integer, 1 rounds to the nearest .1 (etc.).
 #' @param progress logical. Should progress reports be printed? Can be helpful for diagnosis when the function is running slowly.
+#' @param repeat.cues logical. Can cues occur multiple times within a tree?
 #' @param my.tree string. A string representing an FFT in words. For example, \code{my.tree = "If age > 20, predict TRUE. If sex = [m], predict FALSE. Otherwise, predict TRUE"}
 #' @param tree.definitions dataframe. An optional hard-coded definition of trees (see details below). If specified, no new trees are created.
-#' @param comp,do.cart,do.lr,do.rf,do.svm logical. Should alternative algorithms be created for comparison? cart = regular (non-frugal) trees with \code{rpart}, lr = logistic regression with \code{glm}, rf = random forests with \code{randomForest}, svm = support vector machines with \code{e1071}. Setting \code{comp = FALSE} sets all these arguments to FALSE.
+#' @param do.comp,do.cart,do.lr,do.rf,do.svm logical. Should alternative algorithms be created for comparison? cart = regular (non-frugal) trees with \code{rpart}, lr = logistic regression with \code{glm}, rf = random forests with \code{randomForest}, svm = support vector machines with \code{e1071}. Setting \code{comp = FALSE} sets all these arguments to FALSE.
 #' @param store.data logical. Should training / test data be stored in the object? Default is FALSE.
 #' @param object FFTrees. An optional existing FFTrees object. When specified, no new trees are fitted and the existing trees are applied to \code{data} and \code{data.test}.
-#' @param rank.method,verbose depricated arguments.
+#' @param rank.method,verbose,comp depricated arguments.
 #' @param force logical. If TRUE, forces some parameters (like goal) to be as specified by the user even when the algorithm thinks those specifications don't make sense.
 #' @importFrom stats anova predict glm as.formula formula sd
 #' @return An \code{FFTrees} object with the following elements
@@ -83,9 +84,10 @@ FFTrees <- function(formula = NULL,
                     train.p = 1,
                     rounding = NULL,
                     progress = TRUE,
+                    repeat.cues = TRUE,
                     my.tree = NULL,
                     tree.definitions = NULL,
-                    comp = TRUE,
+                    do.comp = TRUE,
                     do.cart = TRUE,
                     do.lr = TRUE,
                     do.rf = TRUE,
@@ -94,11 +96,12 @@ FFTrees <- function(formula = NULL,
                     object = NULL,
                     rank.method = NULL,
                     force = FALSE,
-                    verbose = NULL
+                    verbose = NULL,
+                    comp = NULL
 ) {
 
 
-#
+# #
   # formula = NULL
   # data = NULL
   # data.test = NULL
@@ -129,18 +132,53 @@ FFTrees <- function(formula = NULL,
   # force = FALSE
   # verbose = NULL
   #
-  # formula <- diagnosis ~.
-  # data = heart.train
-  # goal = "bacc"
-  # goal.chase = "bacc"
-  # cost.outcomes = c(0, 1, 1, 0)
+  #
+  # object = heart.fft
+  # data.test = NULL
+  # comp = NULL
+  # do.comp = TRUE
   #
   #
-  # formula = type ~.
-  # data = Zoo_b
+  #
+  # formula = diagnosis_norm ~ .
+  # data = emg_norm
+  # main = "normal"
+  # algorithm = "dfan"
+  # decision.labels = c("Not normal", "Normal")
+  #
+  #
+# Depricated arguments
+{
+  if(is.null(verbose) == FALSE) {
+
+    warning("The argument verbose is depricated. Use progress instead.")
+
+    progress <- verbose
+
+  }
+
+  if(is.null(rank.method) == FALSE) {
+
+    warning("The argument rank.method is depricated. Use algorithm instead.")
+
+    algorithm <- rank.method
+
+  }
+
+  if(is.null(comp) == FALSE) {
+
+    warning("The argument comp is depricated. Use do.comp instead.")
+
+    do.comp <- comp
+
+  }
+
+}
 
 # # Input validation
-{
+
+# If no FFTrees object is specified
+if(is.null(object)) {
 
 
 
@@ -174,6 +212,7 @@ if(is.null(cost.cues) == FALSE) {
 if(is.null(cost.outcomes) & is.null(cost.cues) == FALSE) {
 
   cost.outcomes <- c(0, 0, 0, 0)
+  message("Warning: You specified cue costs but no outcome costs. Results could be misleading.")
 
 } else {
 
@@ -186,27 +225,16 @@ if(is.null(cost.outcomes) & is.null(cost.cues) == FALSE) {
 
 }
 
-# Depricated arguments
-{
-if(is.null(verbose) == FALSE) {
-
-    warning("The argument verbose is depricated. Use progress instead.")
-
-    progress <- verbose
-
-  }
-
-if(is.null(rank.method) == FALSE) {
-
-  warning("The argument rank.method is depricated. Use algorithm instead.")
-
-  algorithm <- rank.method
-
-}
-}
 
 # Validate and clean arguments
 
+if(is.null(object) == FALSE) {
+
+    formula <- object$formula
+    tree.definitions <- object$tree.definitions
+
+}
+
 # tree.definitions
 if(is.null(tree.definitions) == FALSE) {
 
@@ -284,77 +312,34 @@ if(algorithm %in% c("ifan", "dfan") & is.null(max.levels)) {
 
 # Missing manditory arguments
 {
-if(is.null(data)) {stop("Please specify a dataframe in data")}
+if(is.null(data) & is.null(object)) {stop("Please specify training data")}
 
 # Is there a valid formula?
-if(is.null(formula) | class(formula) != "formula") {stop("Please specify a valid formula")}
+if((is.null(formula) | class(formula) != "formula") & is.null(object)) {stop("Please specify a valid formula")}
 
 # Does the named criterion exist?
 crit.name <- paste(formula)[2]
-if(crit.name %in% names(data) == FALSE) {
+if((crit.name %in% names(data) == FALSE) & is.null(object)) {
 
   stop(paste0("The criterion variable ", crit.name, " is not in the data."))}
-}
-
-# If there is an existing FFTrees object, then get the formula
-if(is.null(object) == FALSE) {
-
-  formula <- object$formula
 
 }
 
 
-if(comp == FALSE) {
-
-  do.lr <- FALSE
-  do.cart <- FALSE
-  do.svm <- FALSE
-  do.rf <- FALSE
-
-}
-
-
-
-}
-
 # DEFINE TESTING AND TRAINING DATA [data.train, data.test]
 {
 
 if(is.null(object) == FALSE) {
 
-  data.train.o <- object$data$train
-  data.train <- model.frame(formula = formula,
-                            data = data.train.o)
+  data.train.o <- NULL
+  data.train <- NULL
 
-  cue.train <- data.train[,2:ncol(data.train)]
-  cue.names <- names(cue.train)
+  cue.train <- NULL
+  cue.names <- object$cue.accuracies$train$cue
   n.cues <- length(cue.names)
-  if(ncol(data.train) == 2) {
 
-    cue.train <- data.frame(cue.train)
-
-  }
-
-  crit.train <- data.train[,1]
-
-  crit.name <- names(data.train)[1]
-
-  if(is.null(data.test) == FALSE) {
-
-    data.test.o <- data.test
-
-    if(setequal(names(data.train), names(data.test)) == FALSE) {
-
-      stop("Your training (data) and test (data.test) dataframes do not appear to have the same column names. Please fix and try again.")
-
-    }
-
-    data.test <- model.frame(formula = formula,
-                             data = data.test.o,
-                             na.action = NULL)
-
-    cue.test <- data.test[,2:ncol(data.test)]
-    crit.test <- data.test[,1]
+  crit.train <- NULL
+  crit.name <- NULL
 
   }
 
@@ -373,7 +358,8 @@ if(is.null(object) == TRUE & (train.p == 1 | is.null(data.test) == FALSE)) {
 
   data.train.o <- data
   data.train <- model.frame(formula = formula,
-                            data = data.train.o)
+                            data = data.train.o,
+                            na.action = NULL)
 
   cue.train <- data.train[,2:ncol(data.train)]
   cue.names <- names(cue.train)
@@ -422,7 +408,6 @@ if(is.null(object) == TRUE & (train.p == 1 | is.null(data.test) == FALSE)) {
 ## TRAINING / TESTING RANDOM SPLIT
 if(is.null(data.test) & train.p < 1) {
 
-
   # UPDATE
 
   # randomly sort the original data
@@ -434,9 +419,9 @@ if(is.null(data.test) & train.p < 1) {
 
   data.train.o <- data
 
-
   data.train <- model.frame(formula = formula,
-                            data = data.train.o)
+                            data = data.train.o,
+                            na.action = NULL)
 
   cue.train <- data.train[,2:ncol(data.train)]
   crit.train <- data.train[,1]
@@ -512,7 +497,6 @@ if(is.null(data.test) & train.p < 1) {
 
 }
 
-
 # More validity checks
 {
 
@@ -535,10 +519,13 @@ if(is.null(data.test) & train.p < 1) {
 
     }
 
+    if(is.null(object)) {
+
     data.test <- fac.to.string(data.test)
     data.train <- fac.to.string(data.train)
     cue.train <- fac.to.string(cue.train)
     cue.test <- fac.to.string(cue.test)
+}
 
   }
 
@@ -555,7 +542,6 @@ if(is.null(data.test) & train.p < 1) {
 
   if(is.null(data.test) == FALSE) {
 
-
     if(setequal(names(data.train), names(data.test)) == FALSE) {
 
       stop("Your training (data) and test (data.test) dataframes do not appear to have the same column names. Please fix and try again.")
@@ -612,7 +598,6 @@ if(is.null(data.test) & train.p < 1) {
   }
 }
 }
-}
 
 # GET TREE DEFINITIONS  with grow.FFTrees()
 #  [tree.definitions, cue.accuracies.train]
@@ -623,7 +608,7 @@ if(is.null(data.test) & train.p < 1) {
     tree.definitions <- object$tree.definitions
     cue.accuracies.train <- object$cue.accuracies$train
 
-    }
+  }
 
   if(is.null(object) & is.null(tree.definitions) & is.null(my.tree) & is.null(tree.definitions)) {
 
@@ -640,7 +625,8 @@ if(is.null(data.test) & train.p < 1) {
                                 sens.w = sens.w,
                                 cost.outcomes = cost.outcomes,
                                 cost.cues = cost.cues,
-                                progress = progress)
+                                progress = progress,
+                                repeat.cues = repeat.cues)
 
     tree.definitions <- tree.growth$tree.definitions
     cue.accuracies.train <- tree.growth$cue.accuracies
@@ -670,15 +656,58 @@ if(is.null(data.test) & train.p < 1) {
 
 }
 
-# CALCULATE TEST CUE ACCURACIES [cue.accuracies.test]
-{
+}
 
 if(is.null(object) == FALSE) {
 
-cue.accuracies.train <- object$cue.accuracies$train
+  if(class(object) != "FFTrees") {stop("The object you specified is not of class FFTrees")}
+
+  formula <- object$formula
+  tree.definitions <- object$tree.definitions
+  algorithm <- object$params$algorithm
+  goal <- object$params$goal
+  goal.chase <- object$params$goal.chase
+  sens.w <- object$params$sens.w
+  max.levels <- object$params$max.levels
+  cost.outcomes <- object$params$cost.outcomes
+  cost.cues <- object$params$cost.cues
+  decision.labels <- object$params$decision.labels
+  main <- object$params$main
+  data.desc.train <- object$data.desc$train
+  cue.accuracies.train <- object$cue.accuracies$train
+  treestats.train <- object$tree.stats$train
+  levelstats.train <- object$level.stats$train
+  decision.train <- object$decision$train
+  levelout.train <- object$levelout$train
+  tree.auc.train <- object$auc[1,"FFTrees"]
+  treecost.train <- object$cost$train
+  tree.max <- object$tree.max
+  comp <- object$comp
+  data.train <- NULL
+
+
+  if((is.null(data) == FALSE) & is.null(data.test)) {
+
+    warning("You specified an FFTrees object but not data.test. I will use data as data.test")
+
+    data.test <- data
+    data <- NULL
+
+  }
+
+  data.test.o <- data.test
+  data.test <- model.frame(formula = formula,
+                           data = data.test,
+                           na.action = NULL)
+
+  cue.test <- data.test[,2:ncol(data.test)]
+  crit.test <- data.test[,1]
 
 }
 
+# CALCULATE TEST CUE ACCURACIES [cue.accuracies.test]
+{
+
 if(is.null(data.test) == FALSE & all(is.finite(crit.test)) & is.finite(sd(crit.test)) & is.null(cue.accuracies.train) == FALSE) {
 
   if(sd(crit.test) > 0) {
@@ -703,8 +732,6 @@ cue.accuracies.test <- cuerank(formula = formula,
 
 } else {cue.accuracies.test <- NULL}
 
-
-
 cue.accuracies <- list("train" = cue.accuracies.train, "test" = cue.accuracies.test)
 
 }
@@ -730,13 +757,14 @@ treecost.train <- train.results$treecost
 
 treestats.train <- treestats.train[c("tree", names(classtable(c(1, 0, 1), c(1, 0, 0))), "pci", "mcu")]
 
-
 tree.auc.train <- FFTrees::auc(sens.v = train.results$treestats$sens,
                                spec.v = train.results$treestats$spec)
 }
 
 if(is.null(data.train) == TRUE) {
 
+  if(is.null(object)) {
+
   decision.train <- NULL
   levelout.train <- NULL
   levelstats.train <- NULL
@@ -744,6 +772,7 @@ if(is.null(data.train) == TRUE) {
   tree.auc.train <- NA
   treecost.train <- NULL
 
+  }
 }
 
 if(is.null(data.test) == FALSE) {
@@ -763,7 +792,6 @@ treecost.test <- test.results$treecost
 
 treestats.test <- treestats.test[c("tree",names(classtable(c(1, 0, 1), c(1, 0, 0))), "pci", "mcu")]
 
-
 if(any(is.na(test.results$treestats$sens)) == TRUE) {
 
   tree.auc.test <- NA
@@ -802,27 +830,46 @@ rownames(tree.auc) = c("train", "test")
 
 # FIT COMPETITIVE ALGORITHMS
 {
+
+if(do.comp == FALSE) {
+
+do.lr <- FALSE
+do.cart <- FALSE
+do.svm <- FALSE
+do.rf <- FALSE
+
+}
   if(do.lr | do.cart | do.rf | do.svm) {if(progress) {message("Fitting non-FFTrees algorithms for comparison (you can turn this off with comp = FALSE) ...")}}
 
   # LR
   {
-    if(do.lr) {
+    if(do.lr & ((is.null(object) == FALSE &  is.null(object$comp$lr$model) == FALSE) |
+                is.null(data.train) == FALSE)) {
 
+      if(is.null(object) == FALSE & is.null(object$comp$lr$model) == FALSE) {
 
+        model <- object$comp$lr$model
 
+      } else {model <- NULL}
 
       lr.acc <- comp.pred(formula = formula,
                           data.train = data.train,
                           data.test = data.test,
-                          algorithm = "lr")
+                          algorithm = "lr",
+                          model = model)
 
       lr.stats <- lr.acc$accuracy
       lr.auc <- lr.acc$auc
       lr.model <- lr.acc$model
 
-    }
 
-    if(do.lr == FALSE) {
+      if(is.null(object) == FALSE) {
+
+        lr.stats[,grepl(".train", names(lr.stats))] <- object$comp$lr$stats[,grepl(".train", names(object$comp$lr$stats))]
+
+      }
+
+    } else {
 
       lr.acc <- NULL
       lr.stats <- NULL
@@ -839,21 +886,32 @@ rownames(tree.auc) = c("train", "test")
   # CART
   {
 
-    if(do.cart) {
+    if(do.cart & ((is.null(object) == FALSE &  is.null(object$comp$cart$model) == FALSE) |
+                is.null(data.train) == FALSE)) {
+
+      if(is.null(object) == FALSE & is.null(object$comp$cart) == FALSE) {
+
+        model <- object$comp$cart$model
+
+      } else {model <- NULL}
 
       cart.acc <- comp.pred(formula = formula,
                             data.train = data.train,
                             data.test = data.test,
-                            algorithm = "cart"
-      )
+                            algorithm = "cart",
+                            model = model)
 
       cart.stats <- cart.acc$accuracy
       cart.auc <- cart.acc$auc
       cart.model <- cart.acc$model
 
-    }
+      if(is.null(object) == FALSE) {
 
-    if(do.cart == FALSE) {
+      cart.stats[,grepl(".train", names(cart.stats))] <- object$comp$cart$stats[,grepl(".train", names(object$comp$cart$stats))]
+
+      }
+
+    } else {
 
       cart.acc <- NULL
       cart.stats <- NULL
@@ -869,20 +927,32 @@ rownames(tree.auc) = c("train", "test")
   # rf
   {
 
-    if(do.rf) {
+    if(do.rf & ((is.null(object) == FALSE &  is.null(object$comp$rf$model) == FALSE) |
+                is.null(data.train) == FALSE)){
+
+      if(is.null(object) == FALSE & is.null(object$comp$rf) == FALSE) {
+
+        model <- object$comp$rf$model
+
+      } else {model <- NULL}
 
       rf.acc <- comp.pred(formula = formula,
                           data.train = data.train,
                           data.test = data.test,
-                          algorithm = "rf")
+                          algorithm = "rf",
+                          model = model)
 
       rf.stats <- rf.acc$accuracy
       rf.auc <- rf.acc$auc
       rf.model <- rf.acc$model
 
-    }
+      if(is.null(object) == FALSE) {
 
-    if(do.rf == FALSE) {
+        rf.stats[,grepl(".train", names(rf.stats))] <- object$comp$rf$stats[,grepl(".train", names(object$comp$rf$stats))]
+
+      }
+
+    } else {
 
       rf.acc <- NULL
       rf.stats <- NULL
@@ -898,19 +968,31 @@ rownames(tree.auc) = c("train", "test")
   # svm
   {
 
-    if(do.svm) {
+    if(do.lr & ((is.null(object) == FALSE &  is.null(object$comp$svm$model) == FALSE) |
+                is.null(data.train) == FALSE)){
+
+      if(is.null(object) == FALSE & is.null(object$comp$svm) == FALSE) {
+
+        model <- object$comp$svm$model
+
+      } else {model <- NULL}
 
       svm.acc <- comp.pred(formula = formula,
                            data.train = data.train,
                            data.test = data.test,
-                           algorithm = "svm")
+                           algorithm = "svm",
+                           model = model)
 
       svm.stats <- svm.acc$accuracy
       svm.auc <- svm.acc$auc
       svm.model <- svm.acc$model
-    }
 
-    if(do.svm == FALSE) {
+      if(is.null(object) == FALSE) {
+
+        svm.stats[,grepl(".train", names(svm.stats))] <- object$comp$svm$stats[,grepl(".train", names(object$comp$svm$stats))]
+
+      }
+    } else {
 
       svm.acc <- NULL
       svm.stats <- NULL
@@ -929,6 +1011,7 @@ rownames(tree.auc) = c("train", "test")
 
 # GET BEST TREE
 # Note: Only matters when the algorithm produces multiple trees
+if(is.null(object)) {
 if(goal != "cost") {
 
 tree.max <- which(treestats$train[[goal]] == max(treestats$train[[goal]]))
@@ -940,6 +1023,7 @@ tree.max <- which(treestats$train[[goal]] == min(treestats$train[[goal]]))
 }
 
 if(length(tree.max) > 1) {tree.max <- tree.max[1]}
+}
 
 # Get AUC matrix
 auc <- cbind(tree.auc, lr.auc, cart.auc, rf.auc, svm.auc)
@@ -955,16 +1039,30 @@ if(store.data) {data.ls <- list("train" = data.train, "test" = data.test)} else
 
 # Data descriptions
 
+if(is.null(object)) {
+
 data.desc <- list("train" = data.frame("cases" = nrow(cue.train),
                                        "features" = ncol(cue.train),
                                        "n.pos" = sum(crit.train),
                                        "n.neg" = sum(crit.train == 0),
                                        "criterion.br" = mean(crit.train)),
+                  "test" = data.frame("cases" = NA,
+                                      "features" = NA,
+                                      "n.pos" = NA,
+                                      "n.neg" = NA,
+                                      "criterion.br" = NA)) } else {
+
+data.desc <- list("train" = data.frame("cases" = object$data.desc$train$cases,
+                                       "features" = object$data.desc$train$features,
+                                       "n.pos" = object$data.desc$train$n.pos,
+                                       "n.neg" = object$data.desc$train$n.neg,
+                                       "criterion.br" = object$data.desc$train$criterion.br),
                   "test" = data.frame("cases" = NA,
                                       "features" = NA,
                                       "n.pos" = NA,
                                       "n.neg" = NA,
                                       "criterion.br" = NA))
+                                      }
 
 if(is.null(data.test) == FALSE) {
 
@@ -1011,7 +1109,8 @@ x.FFTrees <- list("formula" = formula,
                                    "cost.outcomes" = cost.outcomes,
                                    "cost.cues" = cost.cues,
                                    "decision.labels" = decision.labels,
-                                   "main" = main),
+                                   "main" = main,
+                                   "repeat.cues" = repeat.cues),
                    "comp" = list("lr" = list("model" = lr.model, "stats" = lr.stats),
                                 "cart" = list("model" = cart.model, "stats" = cart.stats),
                                 "rf" = list("model" = rf.model, "stats" = rf.stats),
