@@ -1,10 +1,10 @@
 
 .onAttach <- function(libname, pkgname) {
-  packageStartupMessage("   a      ")
+  packageStartupMessage("   O      ")
   packageStartupMessage("  / \\     ")
-  packageStartupMessage(" 0   b  ")
+  packageStartupMessage(" F   O  ")
   packageStartupMessage("    / \\   ")
-  packageStartupMessage("   0   1  ")
-  packageStartupMessage("FFTrees v1.3.3. Email: Nathaniel.D.Phillips.is@gmail.com")
+  packageStartupMessage("   F   T  ")
+  packageStartupMessage("FFTrees v1.3.4. Email: Nathaniel.D.Phillips.is@gmail.com")
   packageStartupMessage("FFTrees.guide() opens the package guide. Citation info at citation('FFTrees')")
 }
